# -*- coding: utf-8 -*-
"""SSH YAML Configuration

NAME - SSH YAML Configuration
AUTHOR - Patryk Adamczyk <patrykadamczyk@paipweb.com>
LICENSE - MIT
"""

# Underscore Variables

"""Title of Program"""
__title__ = 'sshyc'
"""Version of Program"""
__version__ = '1.0.2'
"""Author of the module"""
__author__ = 'Patryk Adamczyk'
"""Module License"""
__license__ = 'MIT'
"""Documentation format"""
__docformat__ = 'restructuredtext en'

# Imports

from sshyc.app import main

# Running as sshyc command

if __name__ == '__main__':
    main()
